==> sogo_2.1.1b.orig.tar.gz: SOGo-2.1.1b/UI/SOGoElements/SOGoIEConditional.m <==
/* SOGoIEConditional.m - this file is part of SOGo
 *
 * Copyright (C) 2007 Inverse inc.
 *
 * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#import <NGObjWeb/WOContext.h>
#import <NGObjWeb/WOResponse.h>

#import "SOGoIEConditional.h"

@implementation SOGoIEConditional

- (id) initWithName: (NSString *) name
       associations: (NSDictionary *) associations
	   template: (WOElement *) newTemplate
{
  if ((self = [super initWithName: name
                     associations: associations
                         template: newTemplate]))
    ASSIGN (template, newTemplate);

  return self;
}

- (void) dealloc
{
  [template release];
  [super dealloc];
}

- (void) appendToResponse: (WOResponse *) response
		inContext: (WOContext *) context
{
  [response appendContentString: @"<!--[if IE]>"];
  [template appendToResponse: response inContext: context];
  [response appendContentString: @"<![endif]-->"];
}

@end

==> sogo_5.12.1.orig.tar.gz: SOGo-5.12.1/UI/SOGoElements/SOGoIEConditional.m <==
/* SOGoIEConditional.m - this file is part of SOGo
 *
 * Copyright (C) 2007-2013 Inverse inc.
 *
 * Author: Inverse <info@inverse.ca>
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#import <NGObjWeb/WOContext.h>
#import <NGObjWeb/WOResponse.h>
#import <NGObjWeb/WOAssociation.h>

#import "SOGoIEConditional.h"

@implementation SOGoIEConditional

- (id) initWithName: (NSString *) name
       associations: (NSDictionary *) associations
	   template: (WOElement *) newTemplate
{
  if ((self = [super initWithName: name
                     associations: associations
                         template: newTemplate]))
    {
      ASSIGN (template, newTemplate);
      lte = OWGetProperty(associations, @"lte");
    }

  return self;
}

- (void) dealloc
{
  [template release];
  [lte release];
  [super dealloc];
}

- (void) appendToResponse: (WOResponse *) response
		inContext: (WOContext *) context
{
  NSString *condition;

  if (lte)
    condition = [NSString stringWithFormat: @"<!--[if lte IE %d ]>", [lte intValueInComponent: [context component]]];
  else
    condition = @"<!--[if IE]>";

  [response appendContentString: condition];
  [template appendToResponse: response inContext: context];
  [response appendContentString: @"<![endif]-->"];
}

@end
